<?xml version="1.0" encoding="utf-8"?>
<!--Template to check specified configuration and discretion documents-->
<!--$Date: 2002/03/05 03:00:52 $(UTC)-->

<!--
Copyright (C) The Organization for the Advancement of
Structured Information Standards [OASIS] (2001). All Rights
Reserved.

This document and translations of it may be copied and
furnished to others, and derivative works that comment on
or otherwise explain it or assist in its implementation may
be prepared, copied, published and distributed, in whole
or in part, without restriction of any kind, provided that the
above copyright notice and this paragraph are included on
all such copies and derivative works. However, this
document itself may not be modified in any way, such as by
removing the copyright notice or references to OASIS,
except as needed for the purpose of developing OASIS
specifications, in which case the procedures for copyrights
defined in the OASIS Intellectual Property Rights document
must be followed, or as required to translate it into
languages other than English.

The limited permissions granted above are perpetual and
will not be revoked by OASIS or its successors or assigns.

This document and the information contained herein is
provided on an "AS IS" basis and OASIS DISCLAIMS ALL
WARRANTIES, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO ANY WARRANTY THAT THE USE
OF THE INFORMATION HEREIN WILL NOT INFRINGE
ANY RIGHTS OR ANY IMPLIED WARRANTIES OF
MERCHANTABILITY OR FITNESS FOR A PARTICULAR
PURPOSE.
-->

<!--This will establish global-scope variables for configuration and
    discretion documents, plus check their validity-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<xsl:variable name="configuration" 
              select="document(/submissions/@configuration-href,
                               /submissions/@configuration-href)/suite"/>
<xsl:variable name="discretionary"
              select="document(/submissions/@discretionary-href,
                               /submissions/@discretionary-href)/discretion"/>

<xsl:template name="check-files">
  <xsl:if test="not($configuration)">
    <xsl:variable name="err">
      <xsl:text>Configuration file '</xsl:text>
      <xsl:value-of select="/submissions/@configuration-href"/>
      <xsl:text>' not found, or unexpected document element.</xsl:text>
    </xsl:variable>
    <problem><xsl:copy-of select="$err"/></problem>
    <xsl:message terminate="yes"><xsl:copy-of select="$err"/></xsl:message>
  </xsl:if>
  <xsl:if test="not($discretionary)">
    <xsl:variable name="err">
      <xsl:text>Discretionary file '</xsl:text>
      <xsl:value-of select="/submissions/@discretionary-href"/>
      <xsl:text>' not found, or unexpected document element.</xsl:text>
    </xsl:variable>
    <problem><xsl:copy-of select="$err"/></problem>
    <xsl:message terminate="yes"><xsl:copy-of select="$err"/></xsl:message>
  </xsl:if>
  <xsl:variable name="discretionary-configuration-href"
                select="$discretionary/@configuration-href"/>
  <xsl:if test="$discretionary">
    <xsl:if test="generate-id(document($discretionary-configuration-href,
                                    $discretionary-configuration-href)/suite)
                  !=generate-id($configuration)">
      <problem>Configuration file supplied (<xsl:text/>
        <xsl:value-of select="/submissions/@configuration-href"/>
        <xsl:text>) is not pointing to same file as the </xsl:text>
        <xsl:text>discretionary document's configuration file (</xsl:text>
        <xsl:value-of select="$discretionary-configuration-href"/>
        <xsl:text>)</xsl:text>
      </problem>
    </xsl:if>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>
