<?xml version="1.0" encoding="utf-8"?>
<!--$Id: merge.xsl,v 1.5 2002/04/26 15:07:00 G. Ken Holman Exp $-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<!--
Copyright (C) The Organization for the Advancement of
Structured Information Standards [OASIS] (2001). All Rights
Reserved.

This document and translations of it may be copied and
furnished to others, and derivative works that comment on
or otherwise explain it or assist in its implementation may
be prepared, copied, published and distributed, in whole
or in part, without restriction of any kind, provided that the
above copyright notice and this paragraph are included on
all such copies and derivative works. However, this
document itself may not be modified in any way, such as by
removing the copyright notice or references to OASIS,
except as needed for the purpose of developing OASIS
specifications, in which case the procedures for copyrights
defined in the OASIS Intellectual Property Rights document
must be followed, or as required to translate it into
languages other than English.

The limited permissions granted above are perpetual and
will not be revoked by OASIS or its successors or assigns.

This document and the information contained herein is
provided on an "AS IS" basis and OASIS DISCLAIMS ALL
WARRANTIES, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO ANY WARRANTY THAT THE USE
OF THE INFORMATION HEREIN WILL NOT INFRINGE
ANY RIGHTS OR ANY IMPLIED WARRANTIES OF
MERCHANTABILITY OR FITNESS FOR A PARTICULAR
PURPOSE.
-->
                                   
<xsl:import href="chkfiles.xsl"/>  <!-- declares $configuration, $discretion-->

<xsl:output doctype-system="support/collcat.dtd"/>

<xsl:variable name="documents" 
              select="document(/submissions/@merge-docs-href,
                               /submissions/@merge-docs-href)/docs/doc"/>

<xsl:variable name="exclusions" 
              select="document(/submissions/@merge-exclude-href,
                               /submissions/@merge-exclude-href)/exclusions"/>

<xsl:variable name="submissions" select="/submissions"/>

<xsl:key name="excludes" match="exclude" use="concat(../@submitter,'_',@id)"/>

<xsl:variable name="validate-exclusion-instance-content">
  <xsl:if test="not($submissions)">
    <xsl:message terminate="yes">
      <xsl:text>Unexpected document element: </xsl:text>
      <xsl:value-of select="name(/*)"/>
    </xsl:message>
  </xsl:if>
  <xsl:for-each select="$exclusions/exclude-catalog">
    <xsl:choose>
      <xsl:when test="not($submissions/submission/@submitter=
                          current()/@submitter)">
        <xsl:text>Error</xsl:text>
        <xsl:message>
         <xsl:text>Exclusion of a submitter name not in submission: </xsl:text>
         <xsl:value-of select="@submitter"/>
        </xsl:message>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="test-suite" 
          select="document($submissions/submission[@submitter=
                                     current()/@submitter]/@href)/test-suite"/>
        <xsl:choose>
          <xsl:when test="not($test-suite)">
            <xsl:text>Error</xsl:text>
            <xsl:message>
              <xsl:text>Catalog for submitter not found: </xsl:text>
              <xsl:value-of select="@submitter"/>
            </xsl:message>
          </xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="exclude/@id">
              <xsl:if test="../preceding-sibling::exclude[@id=current()]">
                <xsl:text>Error</xsl:text>
                <xsl:message>
                  <xsl:text>Duplicate entry for id '</xsl:text>
                  <xsl:value-of select="."/>
                  <xsl:text>' in exclusion list for submitter: </xsl:text>
                  <xsl:value-of select="ancestor::exclude-catalog/@submitter"/>
                </xsl:message>
              </xsl:if>
              <xsl:if test="not($test-suite/test-catalog/
                                test-case[@id=current()])">
                <xsl:text>Error</xsl:text>
                <xsl:message>
                  <xsl:text>Excluded id '</xsl:text>
                  <xsl:value-of select="."/>
                  <xsl:text>' not found in catalogue for submitter: </xsl:text>
                  <xsl:value-of select="ancestor::exclude-catalog/@submitter"/>
                </xsl:message>
              </xsl:if>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:for-each>
</xsl:variable>

<xsl:variable name="exit-with-errors">
  <xsl:if test="string($validate-exclusion-instance-content)">
    <xsl:message terminate="yes">
      <xsl:text>Exiting because of errors.</xsl:text>
    </xsl:message>
  </xsl:if>
</xsl:variable>

<xsl:template match="/submissions">
  <test-suite>
    <xsl:call-template name="check-files"/>
    <xsl:copy-of select="$configuration"/>
    <xsl:copy-of select="$discretionary"/>
    <xsl:for-each select="submission">
      <xsl:variable name="catalog" select="document(@href,@href)/test-suite"/>
      <xsl:if test="not($catalog)">
        <xsl:message terminate="yes">
          <xsl:text>Missing file or unexpected document element: </xsl:text>
          <xsl:value-of select="@href"/>
        </xsl:message>
      </xsl:if>
      <xsl:apply-templates select="$catalog/test-catalog">
        <xsl:with-param name="submitter" select="@submitter"/>
      </xsl:apply-templates>
    </xsl:for-each>
  </test-suite>
</xsl:template>

<!--========================================================================-->
<!--default behaviours-->

<xsl:template match="test-catalog">
  <xsl:param name="submitter"/>
  <xsl:copy>
    <xsl:apply-templates>
      <xsl:with-param name="submitter" select="$submitter"/>
    </xsl:apply-templates>
  </xsl:copy>
</xsl:template>

<xsl:template match="test-case">
  <xsl:param name="submitter"/>
  <xsl:variable name="case-id" select="concat($submitter,'_',@id)"/>
  <xsl:copy>
    <xsl:copy-of select="@*"/>
    <xsl:attribute name="id"><!--override copied attribute-->
      <xsl:value-of select="$case-id"/>
    </xsl:attribute>
    <xsl:for-each select="$exclusions">
      <xsl:apply-templates select="key('excludes',$case-id)"/>
    </xsl:for-each>
    <file-path>
      <xsl:variable name="raw-path" select="translate(file-path,'\','/')"/>
      <xsl:value-of select="$submitter"/>/<xsl:text/>
      <xsl:choose>
        <xsl:when test="substring($raw-path,string-length($raw-path),1)='/'">
          <xsl:value-of 
                   select="substring($raw-path,1,string-length($raw-path)-1)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$raw-path"/>
        </xsl:otherwise>
      </xsl:choose>
    </file-path>
    <xsl:copy-of select="node()[not(self::exclude | self::file-path)]"/>
  </xsl:copy>
</xsl:template>

<xsl:template match="exclude"><!--copy content to merged instance-->
  <excluded>
    <xsl:copy-of select="node()"/>
  </excluded>
</xsl:template>

<xsl:template match="creator|date">
  <xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="*">
  <xsl:message>
    <xsl:text/>Element <xsl:value-of select="name(.)"/> not handled.<xsl:text/>
  </xsl:message>
</xsl:template>

</xsl:stylesheet>
